#include "waconfig.h"

#include <kstaticdeleter.h>

WAConfig *WAConfig::mSelf = 0;
static KStaticDeleter<WAConfig> staticWAConfigDeleter;

WAConfig *WAConfig::self()
{
  if ( !mSelf ) {
    staticWAConfigDeleter.setObject( mSelf, new WAConfig() );
    mSelf->readConfig();
  }

  return mSelf;
}

WAConfig::WAConfig(  )
  : TDEConfigSkeleton( TQString::fromLatin1( "wlassistantrc" ) )
{
  mSelf = this;
}

WAConfig::~WAConfig()
{
  if ( mSelf == this )
    staticWAConfigDeleter.setObject( mSelf, 0, false );
}

